==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/language/1/barnraiser_01/me_ties.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');

// HEADERS
$lang['hdr_relations_portable'] = 				"my flock";
$lang['hdr_relations'] = 						"respected";


// ERRORS
$lang['err_no_ties'] = 							"You are not respecting anyone in this site. When viewing an item you can choose to show the author respect. Once you do they will appear here.";
$lang['err_no_portable'] = 						"People who you respect and that have chosen to show you mutual respect are in your flock. You do not have anyone in your flock. Start to contribute and show respect to those people who you admire and over time this list will fill out.";


// SUBMIT BUTTONS
$lang['sub_set_portable'] = 				"add to my flock";

?>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/components/core/language/1/barnraiser_01/me_ties.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');

// HEADERS
$lang['hdr_relations'] = 						"respected";
$lang['hdr_mutual_relations'] =					"mutual respected";

// ERRORS
$lang['err_no_ties'] = 							"You are not respecting anyone in this site. When viewing an item you can choose to show the author respect. Once you do they will appear here.";
$lang['err_no_portable'] = 						"People who you respect and that have chosen to show you mutual respect are in your flock. You do not have anyone in your flock. Start to contribute and show respect to those people who you admire and over time this list will fill out.";


// SUBMIT BUTTON

$lang['sub_remove_respect'] =				"remove respect";

$lang['txt_core_relation'] =					"core-profile";

?>
